@@ -17,7 +17,6 @@ from functools import lru_cache
 from html import escape
 from os.path import isfile
 
-import pkg_resources
 import pytest
 from _pytest.logging import _remove_ansi_escape_sequences
 from py.xml import html
@@ -87,9 +86,18 @@ def pytest_addoption(parser):
 def pytest_configure(config):
     htmlpath = config.getoption("htmlpath")
     if htmlpath:
+        missing_css_files = []
         for csspath in config.getoption("css"):
             if not os.path.exists(csspath):
-                raise OSError(f"No such file or directory: '{csspath}'")
+                missing_css_files.append(csspath)
+
+        if missing_css_files:
+            oserror = (
+                f"Missing CSS file{'s' if len(missing_css_files) > 1 else ''}:"
+                f" {', '.join(missing_css_files)}"
+            )
+            raise OSError(oserror)
+
         if not hasattr(config, "workerinput"):
             # prevent opening htmlpath on worker nodes (xdist)
             config._html = HTMLReport(htmlpath, config)
@@ -474,9 +482,10 @@ class HTMLReport:
         numtests = self.passed + self.failed + self.xpassed + self.xfailed
         generated = datetime.datetime.now()
 
-        self.style_css = pkg_resources.resource_string(
-            __name__, os.path.join("resources", "style.css")
-        ).decode("utf-8")
+        with open(
+            os.path.join(os.path.dirname(__file__), "resources", "style.css")
+        ) as style_css_fp:
+            self.style_css = style_css_fp.read()
 
         if ansi_support():
             ansi_css = [
@@ -526,7 +535,7 @@ class HTMLReport:
                 self.checkbox = html.input(
                     type="checkbox",
                     checked="true",
-                    onChange="filter_table(this)",
+                    onChange="filterTable(this)",
                     name="filter_checkbox",
                     class_="filter",
                     hidden="true",
@@ -597,9 +606,10 @@ class HTMLReport:
             ),
         ]
 
-        main_js = pkg_resources.resource_string(
-            __name__, os.path.join("resources", "main.js")
-        ).decode("utf-8")
+        with open(
+            os.path.join(os.path.dirname(__file__), "resources", "main.js")
+        ) as main_js_fp:
+            main_js = main_js_fp.read()
 
         session.config.hook.pytest_html_report_title(report=self)
 
